# 🐬 blue-rover

🐬 `@rover` is an [abcli](https://github.com/kamangir/awesome-bash-cli) plugin for [ROS](https://www.ros.org/). 

```bash
pip install blue_rover
```

|   |
| --- |
| [`blue-rover`](./blue_rover/docs) [![image](https://github.com/waveshareteam/ugv_rpi/raw/main/media/UGV-Rover-details-23.jpg)](./blue_rover/docs) based on [UGV Beast PI ROS2](https://www.waveshare.com/wiki/UGV_Beast_PI_ROS2). |

---


[![pylint](https://github.com/kamangir/blue-rover/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-rover/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-rover/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-rover/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-rover/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-rover/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-rover.svg)](https://pypi.org/project/blue-rover/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-rover)](https://pypistats.org/packages/blue-rover)

built by 🌀 [`blue_options-4.227.1`](https://github.com/kamangir/awesome-bash-cli), based on 🐬 [`blue_rover-4.33.1`](https://github.com/kamangir/blue-rover).


